@@ -33,29 +33,19 @@ except ImportError:
 
 
 def get_scala_frame():
-    fh = open(os.path.join(TEMPFOLDER, "test.txt"), "w")
-    text = ""
-
     for frame in inspect.stack():
-        module = inspect.getmodule(frame[0])
-        text = text + "frame: {}\n".format(frame[0])
-        if module:
-            # 'win32com.axscript.client.pyscript' might be too specific.
-            # If 'win32com.axscript' is in the call stack, at all, then
-            # it's safe to say we're in ActiveX-land.
-            if 'win32com.axscript' in module.__name__:
-                continue
-                # return frame[0]
-        continue
-    fh.write(text)
-    fh.close()
+        if "Script Block" in frame.__name__:
+            return frame[0]
     return None
 
 
 def variables():
     if current_python_version == PYTHON2:
-
         svars = get_scala_frame().f_globals
+        fh = open(os.path.join(TEMPFOLDER, "test.txt"), "w")
+        text = "{}".format(svars)
+        fh.write(text)
+        fh.close()
 
     elif current_python_version == PYTHON3:
         return scalascript.variables()
